import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardComponentModel} from "../../../stores/DashboardComponentStore";
import {Conditional, HintButton, ModelSelect} from "@rx-suite/ui/build";
import {GoalSetter} from "./GoalSetter";
import {IfTrue} from "@rx-suite/ui/build/components/logic/IfTrue";
import {HorizontalCheckboxField} from "./HorizontalCheckboxField";
import {t} from "@lingui/macro";
import {makeStyles} from "@material-ui/core/styles";

export type DashboardDisplayTypeOptionsProps = {
    component: DashboardComponentModel
}


const useStyles = makeStyles(theme => ({
    wrapper: {
        display: 'flex',
        width: '100%'
    }
}));

export const DashboardDisplayTypeOptions: React.FunctionComponent<DashboardDisplayTypeOptionsProps> = observer(({component}) => {
    const classes = useStyles();
    return <>
        <div className={classes.wrapper}>
            <ModelSelect name={"display_type"} options={component.displayTypes}/>
            <HintButton title={t`Display Type`}>
                {t`The display type lets you choose how the component looks like, such as different varieties of chart`}
            </HintButton>
        </div>
        <Conditional condition={['gauge', 'counter'].includes(component.viewModel.display_type)}>
            <IfTrue>
                <GoalSetter component={component}/>
            </IfTrue>
        </Conditional>
        <Conditional condition={['bar'].includes(component.viewModel.display_type)}>
            <IfTrue>
                <div><HorizontalCheckboxField component={component}/></div>
            </IfTrue>
        </Conditional>
    </>
});
