import {attribute, DataStore, model, Model, Types} from '@rx-suite/data';
import {t} from "@lingui/macro";
import * as yup from 'yup';
import {computed} from "mobx";
import {Parameter} from "./Types";

@model({
    transportLayer: "/api/dashboard_targets",
    routingInfo: {}
})
export class DashboardTargetModel extends Model {
    types: Types = {
        ui_hints: 'json',
        parameters: 'json',
        returns: 'json',
    };
    @attribute({
        validation: yup.string()
    })
    module_id: string = '';

    @attribute({
        label: t`Module`,
        validation: yup.string()
    })
    module_name: string = '';

    @attribute({
        label: t`ID`,
        validation: yup.string()
    })
    dashboard_id: string = '';

    @attribute({
        label: t`Name`,
        validation: yup.string()
    })
    name: string = '';

    @attribute({
        label: t`Description`,
        validation: yup.string()
    })
    desc: string = '';

    @attribute({
        validation: yup.mixed()
    })
    ui_hints: any = {};

    @attribute({
        validation: yup.mixed()
    })
    parameters: { [s: string]: Parameter } = {};

    @attribute({
        validation: yup.mixed()
    })
    returns: any = null;

    @attribute({label: t`Created At`, autoForm: false})
    created_at: Date = new Date();

    @attribute({label: t`Updated At`, autoForm: false})
    updated_at: Date = new Date();

    @computed
    get displayTypes() {
        if (this.ui_hints && this.ui_hints.type) {
            switch (this.ui_hints.type) {
                case 'category_chart':
                    return [
                        {label: t`Bar`, value: 'bar'},
                        {label: t`Pie`, value: 'pie'},
                        {label: t`Radar`, value: 'radar'},
                        {label: t`Polar Area`, value: 'polararea'},
                        {label: t`Counter`, value: 'counter'}
                    ];
                case 'dual_axis_chart':
                    return [
                        {label: t`Bar`, value: 'bar'},
                        {label: t`Line`, value: 'line'},
                        {label: t`Scatter`, value: 'scatter'},
                        {label: t`Heat Map`, value: 'heatmap'},
                    ];
                case 'table':
                    return [{label: t`Table`, value: 'table'}];
                case 'gauge':
                    return [
                        {label: t`Gauge`, value: 'gauge'},
                        {label: t`Counter`, value: 'counter'}
                    ];
                default:
                    return [];
            }
        }
        return [];
    }

}

export const DashboardTargetStore = DashboardTargetModel.store as DataStore<DashboardTargetModel>;
DashboardTargetStore.setLimit(10000);