# == Schema Information
#
# Table name: dashboard_components
#
#  id                  :bigint           not null, primary key
#  data                :string
#  desc                :string
#  display_options     :string
#  display_type        :string
#  last_run_error      :string
#  name                :string
#  parameters          :string
#  refresh_interval    :integer
#  run_token           :string
#  created_at          :datetime         not null
#  updated_at          :datetime         not null
#  dashboard_target_id :bigint
#  run_user_id         :string
#
# Indexes
#
#  index_dashboard_components_on_dashboard_target_id  (dashboard_target_id)
#
# Foreign Keys
#
#  fk_rails_...  (dashboard_target_id => dashboard_targets.id) ON DELETE => cascade ON UPDATE => cascade
#
class DashboardComponent < ApplicationRecord
  belongs_to :dashboard_target
  has_many :dashboard_component_placements
  has_many :dashboards, through: :dashboard_component_placements

  def get_data!
    begin
      if run_token
        RxModule::Authorization.set_request_token(run_token)
      else
        RxModule::Authorization.set_request_token(nil)
      end
      touch
      data = dashboard_target.get_data(parsed_parameters)
      if data
        update(data: data.to_json, last_run_error: nil)
      else
        update(last_run_error: "No data returned")
        Rails.logger.warn { {msg: 'No data returned for component', component: self.as_json} }
      end
    rescue StandardError => err
      update(last_run_error: err.message)
      Rails.logger.error { {msg: 'Dashboard component failed to fetch data', component: self.as_json} }
    end
  end

  def parsed_parameters
    if parameters && parameters != ''
      JSON.parse(parameters)
    else
      {}
    end
  end
end
